@@ -563,7 +563,7 @@ class DataTransform(forms.ModelForm):
                     data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None,
                     initial=[{'parent': self.instance, 'accessory': self.instance.accessory, 'id':str(uuid.uuid4())}],
-                    prefix=self.instance.id
+                    prefix=str(self.instance.id) + 'dataTransformerInlineFormset'
                 )
                 self.nested_data_transformer_form.extra = self.instance.get_children().count() + 1
 
@@ -574,7 +574,7 @@ class DataTransform(forms.ModelForm):
                 instance=self.instance,
                 data=self.data if self.is_bound else None,
                 files=self.files if self.is_bound else None,
-                prefix=self.instance.id
+                prefix=str(self.instance.id) + 'dataTransformerInlineFormset'
             )
             self.nested_data_transformer_form.extra = 0
 
@@ -583,7 +583,7 @@ class DataTransform(forms.ModelForm):
             queryset=self.instance.datatransformerconstants_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            prefix=self.instance.id,
+            prefix=str(self.instance.id)+'DataConstantsTransformerInlineFormset',
             initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
@@ -594,7 +594,7 @@ class DataTransform(forms.ModelForm):
             queryset=self.instance.hardwaredatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            prefix=self.instance.id,
+            prefix=str(self.instance.id)+'HardwareTransformerInlineFormset',
             initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
         )
         self.nested_hardware_outputs_form.extra = self.instance.hardwaredatatransformer_set.count() + 1
@@ -604,7 +604,7 @@ class DataTransform(forms.ModelForm):
             queryset=self.instance.hardwarestatsdatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            prefix=self.instance.id,
+            prefix=str(self.instance.id)+'HardwareStatsTransformerInlineFormset',
             initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
@@ -704,7 +704,7 @@ class DataTransformRoot(forms.ModelForm):
                     data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None,
                     initial=[{'parent': self.instance, 'accessory': self.instance.accessory, 'id':str(uuid.uuid4())}],
-                    prefix=self.instance.id
+                    prefix=str(self.instance.id) + 'dataTransformerInlineFormset',
                 )
                 self.nested_data_transformer_form.extra = self.instance.get_children().count() + 1
 
@@ -714,7 +714,7 @@ class DataTransformRoot(forms.ModelForm):
                     instance=self.instance,
                     data=self.data if self.is_bound else None,
                     files=self.files if self.is_bound else None,
-                    prefix=self.instance.id
+                    prefix=str(self.instance.id) + 'dataTransformerInlineFormset',
                 )
                 self.nested_data_transformer_form.extra = 0
         except Exception as e:
@@ -725,7 +725,7 @@ class DataTransformRoot(forms.ModelForm):
             queryset=self.instance.datatransformerconstants_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            prefix=self.instance.id,
+            prefix=str(self.instance.id)+'DataConstantsTransformerInlineFormset',
             initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
@@ -736,7 +736,7 @@ class DataTransformRoot(forms.ModelForm):
             queryset=self.instance.hardwaredatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            prefix=self.instance.id,
+            prefix=str(self.instance.id)+'HardwareTransformerInlineFormset',
             initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
         )
         self.nested_hardware_outputs_form.extra = self.instance.hardwaredatatransformer_set.count() + 1
@@ -746,7 +746,7 @@ class DataTransformRoot(forms.ModelForm):
             queryset=self.instance.hardwarestatsdatatransformer_set,
             data=self.data if self.is_bound else None,
             files=self.files if self.is_bound else None,
-            prefix=self.instance.id,
+            prefix=str(self.instance.id)+'HardwareStatsTransformerInlineFormset',
             initial=[{'data_transformer': self.instance, 'id': str(uuid.uuid4())}]
 
         )
